==> caps_0.2.0.orig.tar.gz: caps-0.2.0/Pan.h <==
/*
	Pan.h
	
	Copyright 2004 Tim Goetze <tim@quitte.de>
	
	http://quitte.de/dsp/

	panorama with width control

*/
/*
	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 2
	of the License, or (at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
	02111-1307, USA or point your web browser to http://www.gnu.org.
*/

#ifndef _PAN_H_
#define _PAN_H_

#include "dsp/Delay.h"
#include "dsp/OnePole.h"

class PanTap
{
	public:
		int t;
		DSP::OnePoleLP damper;

		d_sample get (DSP::Delay & delay)
			{
				return damper.process (delay[t]);
			}

		void reset (double c)
			{
				damper.set_f (c);
				damper.reset();
			}
};

class Pan
{
	public:
		double fs;
		d_sample pan;

		d_sample gain_l, gain_r;
		d_sample normal;

		DSP::Delay delay;
		PanTap tap;

		template <sample_func_t F>
		void one_cycle (int frames);

		inline void set_pan (d_sample);

	public:
		static PortInfo port_info [];
		d_sample * ports [7];

		d_sample adding_gain;

		void init (double _fs);

		void activate();

		void run (int n)
			{
				one_cycle<store_func> (n);
			}
		
		void run_adding (int n)
			{
				one_cycle<adding_func> (n);
			}
};

#endif /* _PAN_H_ */

==> caps_0.4.2.orig.tar.gz: caps-0.4.2/Pan.h <==
/*
	Pan.h
	
	Copyright 2004-5 Tim Goetze <tim@quitte.de>
	
	http://quitte.de/dsp/

	panorama with width control

*/
/*
	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 2
	of the License, or (at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
	02111-1307, USA or point your web browser to http://www.gnu.org.
*/

#ifndef _PAN_H_
#define _PAN_H_

#include "dsp/Delay.h"
#include "dsp/OnePole.h"

class PanTap
{
	public:
		int t;
		DSP::OnePoleLP damper;

		d_sample get (DSP::Delay & delay)
			{
				return damper.process (delay[t]);
			}

		void reset (double c)
			{
				damper.set_f (c);
				damper.reset();
			}
};

class Pan
: public Plugin
{
	public:
		d_sample pan;

		d_sample gain_l, gain_r;

		DSP::Delay delay;
		PanTap tap;

		template <sample_func_t F>
			void one_cycle (int frames);

		inline void set_pan (d_sample);

	public:
		static PortInfo port_info [];

		void init();
		void activate();

		void run (int n)
			{
				one_cycle<store_func> (n);
			}
		
		void run_adding (int n)
			{
				one_cycle<adding_func> (n);
			}
};

#endif /* _PAN_H_ */
